<p align="center">
  <a href="#">
    <img src="img/pygramsLogoMain.png" alt="Pygrams logo" width="250" height="120">
    <!-- <br>
<img src="img/pygramsLogoMain.png" alt="Pygrams logo" width="250" height="135"> -->
  </a>
</p>

<h3 align="center">PyGrams</h3>

<p align="center">
The Python Package to get all your hustling Programs in one CodeBase
</p>


### Quick start
Several quick start options are available:

- [Download the latest release](https://github.com/Yaseen549/pygrams/archive/refs/tags/v0.0.15.zip)
- Clone the repo: `git clone https://github.com/Yaseen549/pygrams.git`
- Install with [pypi](https://www.pypi.org/): `pip install pygrams`

Read the [Getting started page](https://pygrams.syberstar.com/) for information on the Library contents, examples, and more.


### What's included
Within the download you'll find the following directories and files, logically grouping common assets. You'll see something like this:

## Bugs and feature requests

Have a bug or a feature request? Please first search for existing and closed [issues](https://github.com/Yaseen549/pygrams/issues). If your problem or idea is not addressed yet, [please open a new issue](https://github.com/Yaseen549/pygrams/issues/new).

is there any program missed? <a href="https://github.com/Yaseen549/pygrams/issues/new">Raise an Issue</a>.

### Contribution Guide (Become a Backer)
if you are willing to contribute, here are the steps
1. Fork the Repo.
2. clone the Repo. (git clone REPO)
3. Create a new remote for the upstream repository. (git remote add upstream REPO)
4. Create a new branch. (git checkout -b your-branch-name)
5. Add Codes (git add .)
6. commit your changes. (git commit -m "Adding an awesome feature to your-branch-name")
7. Push the changes to your repository. (git push -u origin your-branch-name)
8. Create a pull request. (We will review it ASAP)

And That's it, get your name in contribution List

### Feature Request Process

Title: Program Name

Description:

Add the description how the function works (or)

Write the complete program and the comments which explains the program. Click <a href="https://github.com/Yaseen549/pygrams/issues/new">here to Request</a>
</div>